@@ -158,13 +158,13 @@ impl ApiError {
         None
     }
 
-    #[cfg(feature = "with-hyper")]
+    #[cfg(feature = "hyper")]
     pub fn into_hyper_response(self) -> hyper::Response<hyper::Body> {
         let problem = self.into_http_api_problem();
         problem.to_hyper_response()
     }
 
-    #[cfg(feature = "with-actix-web")]
+    #[cfg(feature = "actix-web")]
     pub fn into_actix_web_response(self) -> actix_web::HttpResponse {
         let problem = self.into_http_api_problem();
         problem.into()
@@ -264,7 +264,7 @@ impl From<io::Error> for ApiError {
     }
 }
 
-#[cfg(feature = "with-hyper")]
+#[cfg(feature = "hyper")]
 impl From<hyper::Error> for ApiError {
     fn from(error: hyper::Error) -> Self {
         ApiError::with_message_and_cause(
@@ -275,7 +275,7 @@ impl From<hyper::Error> for ApiError {
     }
 }
 
-#[cfg(feature = "with-actix-web")]
+#[cfg(feature = "actix-web")]
 impl From<actix::prelude::MailboxError> for ApiError {
     fn from(error: actix::prelude::MailboxError) -> Self {
         ApiError::with_message_and_cause(
@@ -286,21 +286,21 @@ impl From<actix::prelude::MailboxError> for ApiError {
     }
 }
 
-#[cfg(feature = "with-hyper")]
+#[cfg(feature = "hyper")]
 impl From<ApiError> for hyper::Response<hyper::Body> {
     fn from(error: ApiError) -> hyper::Response<hyper::Body> {
         error.into_hyper_response()
     }
 }
 
-#[cfg(feature = "with-actix-web")]
+#[cfg(feature = "actix-web")]
 impl From<ApiError> for actix_web::HttpResponse {
     fn from(error: ApiError) -> Self {
         error.into_actix_web_response()
     }
 }
 
-#[cfg(feature = "with-actix-web")]
+#[cfg(feature = "actix-web")]
 impl actix_web::error::ResponseError for ApiError {
     fn error_response(&self) -> actix_web::HttpResponse {
         let json = self.to_http_api_problem().json_bytes();
@@ -316,5 +316,5 @@ impl actix_web::error::ResponseError for ApiError {
     }
 }
 
-#[cfg(feature = "with-warp")]
+#[cfg(feature = "warp")]
 impl warp::reject::Reject for ApiError {}
